@@ -93,7 +93,12 @@ class RemoteServer(object):
         return await self._request("HEAD", path, params=params)
 
     async def _request(
-        self, method, path, params, return_json=True, **kwargs,
+        self,
+        method,
+        path,
+        params,
+        return_json=True,
+        **kwargs,
     ):
         kwargs["params"] = _stringify_params(params)
 
@@ -254,8 +259,8 @@ class RemoteDocument(object):
     @raises(404, "Specified database or document ID doesn’t exists ({endpoint})")
     @raises(
         409,
-        "Document with the specified ID ({id}) already exists or specified revision {rev} "
-        "is not latest for target document",
+        "Document with the specified ID ({id}) already exists or specified revision "
+        "{rev} is not latest for target document",
     )
     async def _put(self, data, **params):
         _, json = await self._database._remote._put(self.endpoint, data, params)
@@ -281,8 +286,8 @@ class RemoteDocument(object):
     )
     @raises(
         409,
-        "Document with the specified ID already exists or specified revision is not latest for "
-        "target document",
+        "Document with the specified ID already exists or specified revision is not "
+        "latest for target document",
     )
     async def _copy(self, destination, **params):
         _, json = await self._database._remote._request(
